#

##

    	geo

    	possibilities

    		Inconsistencies
    		Leap Years (February 29 added)
    			* Every Four Years

    			if (year is not divisible by 4) then (it is a common year)
    			else if (year is not divisible by 100) then (it is a leap year)
    			else if (year is not divisible by 400) then (it is a common year)
    			else (it is a leap year)

    			function isLeapYear(year) {
    				if (year % 4 === 0) {

    				}
    			}

    		Leap Seconds